@@ -4,10 +4,11 @@
 #' @param details Logical. Check available logs and results.
 #' @param tz Character. Local time zone. See OlsonNames() or use Sys.timezone().
 #' @param upload.time Character. UTC upload time for logs "hh:mm" or "hh:mm:ss".
+#' @param check.days Numeric or Integer. Number of days back to check.
 #' @export
 
 logInfo <- function(details = FALSE, tz = Sys.timezone(), 
-  upload.time = "17:00") {
+  upload.time = "17:00", check.days = 7) {
 
   if (!curl::has_internet()) stop("Check internet connection.", call. = FALSE)
   utc.date.time <- utc()
@@ -61,39 +62,43 @@ logInfo <- function(details = FALSE, tz = Sys.timezone(),
     }
   }
   
-  rstudio.status <- ifelse(rstudio.results.available, "Yes.", "No.")
+  log.status <- ifelse(rstudio.results.available, "Yes.", "No.")
   cranlogs.status <- ifelse(cranlogs.results.available, "Yes.", "No.")
   
   out <- list("Today's log/result" = today.log,
-              "Today's log on Posit/RStudio?" = rstudio.status,
+              "Today's log on Posit/RStudio?" = log.status,
               "Today's result on 'cranlogs'?" = cranlogs.status,
               status = status)
   
   if (details) {
-    omega <- 4
-    rev.last.wk <- seq(utc.date - 1, utc.date - omega, by = -1)
+    rev.dates <- seq(utc.date - 1, utc.date - check.days, by = -1)
     
-    last.available <- vapply(rev.last.wk, function(x) {
+    logs.available <- vapply(rev.dates, function(x) {
       tmp.url <- paste0(rstudio.url, year, '/', x, ".csv.gz")
       RCurl::url.exists(tmp.url)
     }, logical(1L))
+
+    logs.last.available <- rev.dates[logs.available][1]
+
+    cranlogs.available <- try(cranlogs::cran_downloads(
+      from = rev.dates[check.days], to = rev.dates[1]), silent = TRUE)
     
-    rstudio.last.available <- rev.last.wk[last.available][1]
-    
-    cranlogs.available <- try(cranlogs::cran_downloads(from = 
-      rev.last.wk[omega], to = rev.last.wk[1]), silent = TRUE)
     if (any(class(cranlogs.available) == "try-error")) {
       cran.last.available <- NA
     } else {
-      sel <- cranlogs.available$count != 0
-      cran.last.available <- max(cranlogs.available[sel, "date"])
+      obs <- cranlogs.available$count != 0
+      if (any(obs)) {
+        cran.last.available <- max(cranlogs.available[obs, "date"])  
+      } else if (all(!obs)) {
+        cran.last.available <- NA
+      }
     }
     
-    note <- paste0("Posit/RStudio ", "(", rstudio.last.available, ")",
+    note <- paste0("Posit/RStudio ", "(", logs.last.available, ")",
                    "; 'cranlogs' ", "(", cran.last.available, ").")
     
     out <- list("Today's log/result" = today.log,
-                "Today's log on Posit/RStudio?" = rstudio.status,
+                "Today's log on Posit/RStudio?" = log.status,
                 "Today's results on 'cranlogs'?" = cranlogs.status,
                 "Available log/result" = note,
                 "Current date-time" = paste0(format(Sys.time(), date.fmt)),
