@@ -27,22 +27,22 @@ versionPlot <- function() {
 
   geom.col <- grDevices::adjustcolor("red", alpha.f = 0.5)
 
-  ggplot2::ggplot(data = pkg.data, ggplot2::aes(x = .data$pkg.id, y = .data$pct.obs.exp)) +
+  ggplot2::ggplot(data = pkg.data,
+      ggplot2::aes(x = .data$pkg.id, y = .data$pct.obs.exp)) +
     ggplot2::geom_line(col = geom.col, linewidth = 0.5) +
 
     # https://github.com/tidyverse/ggplot2/issues/2963
     # geom_vline(xintercept) --> geom_vline(aes(xintercept))
     ggplot2::geom_vline(aes(xintercept = 99.5), col = "black", 
       linetype = "dashed") +
-
-    ggplot2::xlab("Sample Package ID") +
-    ggplot2::ylab("Percent") +
+    ggplot2::labs(x ="Sample Package ID") +
+    ggplot2::labs(y = "Percent") +
     sugrrants::facet_calendar(~ as.Date(date), week_start = 7) +
     ggplot2::theme_bw() +
     ggplot2::theme(panel.grid.minor = ggplot2::element_blank(),
                    panel.grid.major = ggplot2::element_blank(),
-                  plot.title = ggplot2::element_text(hjust = 0.5)) +
+                   plot.title = ggplot2::element_text(hjust = 0.5)) +
     ggplot2::scale_y_continuous(breaks = c(0, 50, 100), limits = c(-10, 110)) +
     ggplot2::scale_x_continuous(breaks = 100) +
-    ggplot2::ggtitle(paste(titleA, titleB))
+    ggplot2::labs(title = paste(titleA, titleB))
 }
